Crate rustlite_wal

Crate rustlite_wal 

RustLite WAL (Write-Ahead Log)

Write-Ahead Log implementation for RustLite, providing durable, crash-recoverable transaction logging.

⚠️ Internal Implementation Detail

This crate is an internal implementation detail of RustLite.

Users should depend on the main rustlite crate instead, which provides the stable public API. This crate’s API may change without notice between minor versions.

# In your Cargo.toml - use the main crate, not this one:
[dependencies]
rustlite = "0.2"

Re-exports

pub use reader::WalReader;
pub use record::RecordPayload;
pub use record::RecordType;
pub use record::WalRecord;
pub use recovery::RecoveryManager;
pub use recovery::RecoveryStats;
pub use segment::SegmentInfo;
pub use segment::SegmentManager;
pub use writer::WalWriter;

Modules

reader
record
recovery
segment
writer

Structs

WalConfig
WAL configuration options
WalManager
WAL manager coordinates log writing and recovery

Enums

SyncMode
Sync mode for WAL writes